@@ -3,16 +3,16 @@ from mlplatform_lib.dataclass import (
     TableDescInfo,
     InsertTupleObject,
     TableFromDefaultDataSourceInfo,
+    DataObjectInfoList,
+    DbSourceDataObjectCandidate,
+    DbSourceDataObjectCandidateList,
 )
 from dataclasses import dataclass
 from enum import Enum
 import json
 import requests
-import pandas as pd
-import os
-import time
 from typing import Optional, Dict, List, Union, Tuple
-from mlplatform_lib.utils.dataclass_utils import from_dict
+from mlplatform_lib.utils.dataclass_utils import from_dict, to_dict
 
 
 HYPERDATA_DATETIME_FORMAT = "%Y.%m.%d %H.%M.%S"
@@ -53,8 +53,9 @@ class HyperdataRequestResult:
 
 
 class HyperdataHttpClient:
-    def __init__(self, hd_addr):
+    def __init__(self, hd_addr, api_client: ApiClient):
         self.base_url = hd_addr + "/hyperdata/web-service"
+        self.proauth_client = ProauthHttpClient(proauth_addr=api_client.proauth_addr)
 
     def send_request(
         self,
@@ -62,9 +63,11 @@ class HyperdataHttpClient:
         rest: Optional[dict],
         query: Optional[dict],
         data: Optional[dict],
-        auth: HyperdataUserAuth,
         request_type: HyperdataRequestType,
     ) -> HyperdataRequestResult:
+        auth = Auth()
+        print("====auth test====")
+        print(auth.refreshToken)
         headers = {
             "Content-Type": "application/json",
             "Authorization": auth.authorization,
@@ -80,6 +83,9 @@ class HyperdataHttpClient:
         if data is None:
             data = {}
 
+        if service == "dataObjectTuple":
+            headers["doType"] = "inferenceResult"
+
         if request_type == HyperdataRequestType.DOWNLOAD:
             headers["ProObjectWebFileTransfer"] = "true"
             query["action"] = "Download"
@@ -116,6 +122,7 @@ class HyperdataHttpClient:
             return HyperdataRequestResult(None, None, None)
 
         if response.status_code == 200:
+            response.content.code
             if request_type == HyperdataRequestType.DOWNLOAD:
                 return HyperdataRequestResult(response.content, None, response.status_code)
             else:
@@ -123,30 +130,55 @@ class HyperdataHttpClient:
                     response.json(), response.content.decode(), response.status_code
                 )
         else:
-            print(response.content.decode())
-            print(
-                (
-                    f"cannot connect to {self.base_url}. "
-                    f"hyperdata server returns status code {response.status_code}"
+            if response.json()['exception']['code'] == "HDE-0403":
+                print("====auth update test====")
+                result, refresh_token, access_token = self.proauth_client.update_token(auth.refreshToken)
+                if result == "true":
+                    auth.refreshToken = refresh_token
+                    auth.accessToken = access_token
+                    headers["Authorization"] = auth.accessToken
+
+                    if request_type == HyperdataRequestType.READ or request_type == HyperdataRequestType.DOWNLOAD:
+                        response = requests.get(url, headers=headers, data=json.dumps(data), verify=False)
+                    elif request_type == HyperdataRequestType.CREATE:
+                        response = requests.post(url, headers=headers, data=json.dumps(data), verify=False)
+                    elif request_type == HyperdataRequestType.UPDATE:
+                        response = requests.put(url, headers=headers, data=json.dumps(data), verify=False)
+                    elif request_type == HyperdataRequestType.DELETE:
+                        response = requests.delete(url, headers=headers, data=json.dumps(data), verify=False)
+                    elif request_type == HyperdataRequestType.READ_WITH_FORM_DATA:
+                        response = requests.get(url, headers=headers, data=json.dumps(data), verify=False)
+                    else:
+                        return HyperdataRequestResult(None, None, None)
+
+                else:
+                    raise HyperdataRequestException(response.content.decode(), response.status_code)
+                
+            else:    
+                print(response.content.decode())
+                print(
+                    (
+                        f"cannot connect to {self.base_url}. "
+                        f"hyperdata server returns status code {response.status_code}"
+                    )
                 )
-            )
-            raise HyperdataRequestException(response.content.decode(), response.status_code)
+                raise HyperdataRequestException(response.content.decode(), response.status_code)
 
     # TODO: hyperdata datasource에 do 정보들을 다가지고 오는 so 구현 필요
-    def get_do_list(self, auth: HyperdataUserAuth) -> List[DataObject]:
+    def get_do_list(self) -> List[DataObject]:
         result = self.send_request(
-            "automlExperimentDataObjectList", {}, {}, {}, auth, HyperdataRequestType.READ
+            "automlExperimentDataObjectList", {}, {}, {}, HyperdataRequestType.READ
         )
         result_data = result.data["dto"]["dataObjectInfoList"]
 
         do_list = []
         for do_info in result_data:
-            do_list.append(self.get_do_info(auth, do_info["id"]))
+            do_list.append(self.get_do_info(do_info["id"]))
         return do_list
 
-    def get_do_simple_list(self, auth: HyperdataUserAuth) -> dict:
+    def get_do_simple_list(self) -> dict:
         result = self.send_request(
-            "automlExperimentDataObjectList", {}, {}, {}, auth, HyperdataRequestType.READ
+            "automlExperimentDataObjectList", {}, {}, {}, HyperdataRequestType.READ
         )
         result_data = result.data["dto"]["dataObjectInfoList"]
         do_list = {}
@@ -154,9 +186,18 @@ class HyperdataHttpClient:
             do_list[do_info["name"]] = do_info["id"]
         return do_list
 
-    def get_do_info(self, auth: HyperdataUserAuth, do_id: int) -> DataObject:
+    def get_do_list_by_datasource_id(self, auth: HyperdataUserAuth, datasource_id: int) -> DataObjectInfoList:
         result = self.send_request(
-            "", {"dataobjects": do_id}, {"action": "Detail"}, {}, auth, HyperdataRequestType.READ,
+            "dataobjects", {"datasources": datasource_id}, {}, {}, auth, HyperdataRequestType.READ
+        )
+        result_data = result.data["dto"]["dataObjectInfoList"]
+        return DataObjectInfoList(
+            data_object_info_list=[from_dict(DataObject, do_info) for do_info in result_data]
+        )
+
+    def get_do_info(self, do_id: int) -> DataObject:
+        result = self.send_request(
+            "", {"dataobjects": do_id}, {"action": "Detail"}, {}, HyperdataRequestType.READ,
         )
         return from_dict(DataObject, result.data["dto"])
 
@@ -172,14 +213,13 @@ class HyperdataHttpClient:
 
     # 아직 공식 hyperdata so에서 값이 이상하게 들어와 직접 만든걸 사용
     def get_do_samples(
-        self, auth: HyperdataUserAuth, dataobject_id: int, sample_size: int
+        self, dataobject_id: int, sample_size: int
     ) -> HyperdataRequestResult:
         result = self.send_request(
             "automlExperimentDataObjectSample",
             {"dataobjects": dataobject_id},
             {"size": sample_size},
             {},
-            auth,
             HyperdataRequestType.READ,
         )
         fixed_table_string = []
@@ -191,45 +231,21 @@ class HyperdataHttpClient:
         result.data["dto"]["tableString"] = json.dumps(fixed_table_string)
         return result
 
-    def get_do_detail_info(self, auth: HyperdataUserAuth, do_id: int):
+    def get_do_detail_info(self, do_id: int):
         result = self.send_request(
             "",
             {"isedit": 0, "subtype": "Table", "dataobjects": do_id},
             {"action": "Desc"},
             {},
-            auth,
             HyperdataRequestType.READ,
         )
         return from_dict(TableDescInfo, result.data["dto"])
 
-    def get_do_to_csv(
-        self, experiment_id: str, do_id: str, char_encoding: str, full_path: str, auth: HyperdataUserAuth
-    ) -> pd.DataFrame:
-        res = self.send_request(
-            "dataobjects",
-            {},
-            {"action": "OutputFileDir"},
-            {"dataobjectId": do_id, "experimentId": experiment_id},
-            auth,
-            HyperdataRequestType.UPDATE,
-        )
-        if res.status_code == 200:
-            print("Success")
-            while os.path.exists(full_path) is False:
-                print("Waiting")
-                time.sleep(0.1)
-            result = pd.read_csv(full_path, encoding=char_encoding)
-        else:
-            print("Fail")
-            print(res.json())
-            result = None
-        return result
-
     def download_do_to_csv(
-        self, auth: HyperdataUserAuth, do_id: int
+        self, do_id: int
     ) -> Tuple[HyperdataRequestResult, str, str]:
         result = self.send_request(
-            "", {"dataobjects": do_id}, {"action": "Detail"}, {}, auth, HyperdataRequestType.READ,
+            "", {"dataobjects": do_id}, {"action": "Detail"}, {}, HyperdataRequestType.READ,
         )
 
         table_name = result.data["dto"]["sourceTableName"]
@@ -242,7 +258,6 @@ class HyperdataHttpClient:
                 {"isedit": 0, "subtype": subtype, "dataobjects": do_id},
                 {"action": "Desc"},
                 {},
-                auth,
                 HyperdataRequestType.READ,
             )
             cols = result.data["dto"]["colInfoList"]
@@ -263,12 +278,11 @@ class HyperdataHttpClient:
                     "selectorProperty": {"columnSelectOptions": col_select_opts, "rowSelectOptions": []},
                     "outputTable": {"name": table_name},
                 },
-                auth,
                 HyperdataRequestType.DOWNLOAD,
             )
 
         result = self.send_request(
-            "", {"datasources": datasource_id}, {"action": "Detail"}, {}, auth, HyperdataRequestType.READ,
+            "", {"datasources": datasource_id}, {"action": "Detail"}, {}, HyperdataRequestType.READ,
         )
         do_type_check = None
         try:
@@ -288,7 +302,6 @@ class HyperdataHttpClient:
                     {"dataobjects": do_id},
                     {"action": "Download"},
                     {},
-                    auth,
                     HyperdataRequestType.DOWNLOAD,
                 ),
                 result.data["dto"]["fileSourceParam"]["fieldDelimiter"],
@@ -297,59 +310,66 @@ class HyperdataHttpClient:
         else:
             return _download_do_to_csv(), ",", "\\n"
 
-    def get_default_datasource_id(self, auth: HyperdataUserAuth) -> int:
-        result = self.send_request("dataSourceDefault", {}, {}, {}, auth, HyperdataRequestType.READ)
+    def get_default_datasource_id(self) -> int:
+        result = self.send_request("dataSourceDefault", {}, {}, {}, HyperdataRequestType.READ)
         return int(result.data["dto"]["defaultDataSourceId"])
 
+    def get_dataobject_tables(self, auth: HyperdataUserAuth, datasource_id: int):
+        result = self.send_request(
+            "", {"datasources": datasource_id}, {"action": "Desc"}, {}, auth, HyperdataRequestType.READ
+        )
+
+        result_data = result.data["dto"]["DbSourceDataObjectCandidate"]
+        return DbSourceDataObjectCandidateList(
+            db_source_data_object_candidate=[
+                from_dict(DbSourceDataObjectCandidate, table_info) for table_info in result_data
+            ]
+        )
+
     def create_dataobject_table(
         self,
-        auth: HyperdataUserAuth,
         datasource_id: int,
         table_from_default_data_source: TableFromDefaultDataSourceInfo,
-    ) -> HyperdataRequestResult:
-        data = table_from_default_data_source.__dict__
-        data["columnList"] = [col_info.__dict__ for col_info in data["columnList"]]
-
-        return self.send_request(
+    ) -> None:
+        self.send_request(
             "dataobjects",
             {"datasources": datasource_id},
             {"action": "CreateTable"},
-            data,
-            auth,
+            to_dict(table_from_default_data_source),
             HyperdataRequestType.CREATE,
         )
 
     def create_dataobjects(
-        self, auth: HyperdataUserAuth, datasource_id: int, dataobjects: List[DataObject]
-    ) -> HyperdataRequestResult:
-        dataobjects = [dataobject.__dict__ for dataobject in dataobjects]
-        return self.send_request(
+        self, datasource_id: int, dataobjects: DataObjectInfoList
+    ) -> DataObjectInfoList:
+        result = self.send_request(
             "dataobjects",
             {"datasources": datasource_id},
             {},
-            {"dataObjectInfoList": dataobjects},
-            auth,
+            to_dict(dataobjects),
             HyperdataRequestType.CREATE,
         )
+        result_data = result.data["dto"]["dataObjectInfoList"]
+        return DataObjectInfoList(
+            data_object_info_list=[from_dict(DataObject, do_info) for do_info in result_data]
+        )
 
     def insert_dataobject_tuple(
-        self, auth: HyperdataUserAuth, dataobject_id: int, insert_tuple_objects: InsertTupleObject,
+        self, dataobject_id: int, insert_tuple_objects: InsertTupleObject,
     ) -> HyperdataRequestResult:
         return self.send_request(
             "dataObjectTuple",
             {"dataobjects": dataobject_id},
             {},
             {"jsonString": json.dumps(insert_tuple_objects.__dict__)},
-            auth,
             HyperdataRequestType.UPDATE,
         )
 
-    def delete_dataobjects(self, auth: HyperdataUserAuth, dataobject_id: int) -> HyperdataRequestResult:
+    def delete_dataobjects(self, dataobject_id: int) -> HyperdataRequestResult:
         return self.send_request(
             "datasources",
             {},
             {},
             {"dataobjectId": [dataobject_id], "datasourceId": [], "fileType": []},
-            auth,
             HyperdataRequestType.DELETE,
         )
