@@ -1,7 +1,7 @@
 from mlplatform_lib.api_client import ApiClient, RunMode
-from mlplatform_lib.mlplatform.mlplatform_http_client import MlPlatformUserAuth
 from mlplatform_lib.mllab.mllab_http_client import MllabHttpClient
-from mlplatform_lib.hyperdata.hyperdata_http_client import HyperdataHttpClient, HyperdataUserAuth
+from mlplatform_lib.hyperdata.hyperdata_http_client import HyperdataHttpClient
+from mlplatform_lib.hyperdata.hyperdata_api import HyperdataApi
 from mlplatform_lib.dataclass.model.model_dto import ModelDto
 from mlplatform_lib.dataclass import (
     InsertTupleObject,
@@ -19,7 +19,7 @@ class MllabImageType:
     TORCH = "torch_v1.6.0"
 
 
-if os.environ["image"] == MllabImageType.TENSORFLOW_V1 or MllabImageType.TENSORFLOW_V2:
+if os.environ["image"] == MllabImageType.TENSORFLOW_V1 or os.environ["image"] == MllabImageType.TENSORFLOW_V2:
     import tensorflow as tf
 elif os.environ["image"] == MllabImageType.TORCH:
     import torch
@@ -33,25 +33,15 @@ class MllabApi:
 
         if api_client.run_mode == RunMode.KUBERNETES:
             self.mllab_mlplatform_client = MllabHttpClient(mlplatform_addr=os.environ["mlplatformAddr"])
-            self.mllab_hyperdata_client = HyperdataHttpClient(self.api_client.hyperdata_addr)
-            self.mlplatform_auth = MlPlatformUserAuth(
-                project_id=self.api_client.projectId,
-                user_id=self.api_client.userId,
-                authorization=self.api_client.Authorization,
-                authorization_type=self.api_client.authorizationType,
-            )
-            self.hyperdata_auth = HyperdataUserAuth(
-                project_id=self.api_client.projectId,
-                user_id=self.api_client.userId,
-                authorization=self.api_client.Authorization,
-            )
+            self.mllab_hyperdata_client = HyperdataHttpClient(hd_addr=self.api_client.hyperdata_addr, api_client=self.api_client)
+            self.mllab_hyperdata_api = HyperdataApi(api_client=self.api_client)
         self.experiment_id = self.api_client.experiment_id
         self.image = os.environ["image"]
 
     def get_model_list(self) -> Optional[List[ModelDto]]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             return self.mllab_mlplatform_client.get_model_list(
-                experiment_id=self.experiment_id, auth=self.mlplatform_auth
+                experiment_id=self.experiment_id
             )
         else:
             print("Current mode is local, Skip get_list_model.")
@@ -61,7 +51,7 @@ class MllabApi:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             if model_path is None:
                 latest_model_dto = self.mllab_mlplatform_client.get_latest_model(
-                    experiment_id=self.experiment_id, auth=self.mlplatform_auth
+                    experiment_id=self.experiment_id
                 )
                 model_path = latest_model_dto.model_path
 
@@ -111,14 +101,13 @@ class MllabApi:
                             fout.write(line)
 
             model_dto = self.mllab_mlplatform_client.get_model_by_id(
-                experiment_id=self.experiment_id, train_id=self.api_client.train_id, auth=self.mlplatform_auth
+                experiment_id=self.experiment_id, train_id=self.api_client.train_id
             )
             model_dto.model_path = export_dir
             return self.mllab_mlplatform_client.update_model(
                 experiment_id=self.experiment_id,
                 train_id=self.api_client.train_id,
-                dto= model_dto,
-                auth=self.mlplatform_auth,
+                dto=model_dto
             )
         else:
             print("Current mode is local, Skip get_list_do.")
@@ -126,7 +115,7 @@ class MllabApi:
 
     def get_do_list(self) -> dict:
         if self.api_client.run_mode == RunMode.KUBERNETES:
-            return self.mllab_hyperdata_client.get_do_simple_list(auth=self.hyperdata_auth)
+            return self.mllab_hyperdata_client.get_do_simple_list()
         else:
             print("Current mode is local, Skip get_list_do.")
             return None
@@ -134,18 +123,23 @@ class MllabApi:
     def get_do(self, do_id: str, char_encoding="euc-kr") -> pd.DataFrame:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             file_name = do_id + ".csv"
-            dir_name = self.api_client.pvc_mount_path + "/data/"
-            full_path = dir_name + file_name
+            dir_name = self.api_client.pvc_mount_path + "/data"
+            full_path = dir_name + "/" + file_name
             if os.path.exists(full_path):
                 result = pd.read_csv(full_path, encoding=char_encoding)
                 return result
-            return self.mllab_hyperdata_client.get_do_to_csv(
-                experiment_id=self.experiment_id,
+           
+            do_path = self.mllab_hyperdata_api.download_csv(
                 do_id=do_id,
-                char_encoding=char_encoding,
-                full_path=full_path,
-                auth=self.hyperdata_auth,
+                data_rootpath=dir_name
             )
+
+            if os.path.exists(do_path) :
+                result = pd.read_csv(do_path, encoding=char_encoding)
+            else :
+                print("Fail")
+                result = None
+            return result
         else:
             print("Current mode is local, Skip get_do.")
             return None
@@ -153,7 +147,7 @@ class MllabApi:
     def get_do_meta(self, do_id: str) -> List[TableColumnInfo]:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             tableDescInfo = self.mllab_hyperdata_client.get_do_detail_info(
-                do_id=do_id, auth=self.hyperdata_auth
+                do_id=do_id
             )
             return tableDescInfo.col_info_list
         else:
@@ -164,25 +158,24 @@ class MllabApi:
         if self.api_client.run_mode == RunMode.KUBERNETES:
             print(self.api_client.inference_id)
             if self.api_client.inference_id is not None:
-                file_path = (
-                    self.api_client.pvc_mount_path
-                    + "/inference/inference-"
-                    + self.api_client.inference_id
-                    + "/inference-result.csv"
+                file_dir = (
+                    self.api_client.pvc_mount_path + "/inference/inference-" + self.api_client.inference_id
                 )
+                file_path = file_dir + "/inference-result.csv"
+                if not os.path.isdir(file_dir):
+                    os.mkdir(file_dir)
                 input_data.to_csv(file_path, index=False, header=True)
             else:
                 print("inference id is None")
                 return False
 
             inference_dto = self.mllab_mlplatform_client.get_inference_by_id(
-                experiment_id=self.experiment_id, inference_id=self.api_client.inference_id, auth=self.mlplatform_auth
+                experiment_id=self.experiment_id,
+                inference_id=self.api_client.inference_id
             )
             inference_dto.inference_path = file_path
             self.mllab_mlplatform_client.update_inference(
-                experiment_id=self.experiment_id,
-                dto= inference_dto,
-                auth=self.mlplatform_auth,
+                experiment_id=self.experiment_id, dto=inference_dto
             )
 
             insert_tuple_object = InsertTupleObject(
@@ -191,7 +184,7 @@ class MllabApi:
                 tableData=input_data.values.tolist(),
             )
             res = self.mllab_hyperdata_client.insert_dataobject_tuple(
-                auth=self.hyperdata_auth, dataobject_id=do_id, insert_tuple_objects=insert_tuple_object
+                dataobject_id=do_id, insert_tuple_objects=insert_tuple_object
             )
             if res.status_code == 200:
                 return True
