@@ -8,7 +8,7 @@ from datetime import datetime
 from mlplatform_lib.utils.dataclass_utils import to_dict, from_dict
 
 
-MLPLATFORM_TIMSTAMP_FORMAT = "%Y-%m-%dT%H:%M:%S"
+MLPLATFORM_TIMSTAMP_FORMAT = "%Y.%m.%d %H:%M:%S"
 
 
 class MlPlatformRequestException(Exception):
@@ -51,10 +51,11 @@ class MlPlatformHttpClient:
         service: str,
         rest: Optional[dict],
         query: Optional[dict],
-        data: Union[Optional[dict], Path],
-        auth: MlPlatformUserAuth,
+        data: Union[Optional[dict], Path]
         request_type: MlPlatformRequestType,
     ) -> MlPlatformRequestResult:
+        auth = Auth()
+        
         headers = {
             "Content-Type": "application/json",
             "Authorization": auth.authorization,
@@ -113,14 +114,13 @@ class MlPlatformHttpClient:
             raise MlPlatformRequestException(response.content.decode(), response.status_code)
 
     def upload_inference_csv(
-        self, experiment_id: int, inference_id: int, inference_csv_path: str, auth: MlPlatformUserAuth
+        self, experiment_id: int, inference_id: int, inference_csv_path: str
     ) -> None:
         self.send_request(
             "file",
             {"experiments": experiment_id, "inferences": inference_id},
             {},
             Path(inference_csv_path),
-            auth,
             MlPlatformRequestType.CREATE,
         )
 
@@ -129,8 +129,7 @@ class MlPlatformHttpClient:
         experiment_id: int,
         train_id: int,
         model_id: int,
-        model_info: ModelInfoDto,
-        auth: MlPlatformUserAuth,
+        model_info: ModelInfoDto
     ) -> ModelInfoDto:
         model_info.finished_time = datetime.now().strftime(MLPLATFORM_TIMSTAMP_FORMAT)
 
@@ -139,7 +138,6 @@ class MlPlatformHttpClient:
             {"experiments": experiment_id, "trains": train_id, "models": model_id},
             {},
             to_dict(model_info),
-            auth,
             MlPlatformRequestType.CREATE,
         )
         return from_dict(ModelInfoDto, result.data)
